Package: Hmisc
Version: 5.2-6
Date: 2026-06-18
Title: Harrell Miscellaneous
Authors@R: 
    c(person(given   = "Frank E",
             family  = "Harrell Jr",
             role    = c("aut", "cre"),
             email   = "fh@fharrell.com",
             comment = c(ORCID = "0000-0002-8271-5493")),
      person(given   = "Cole",
             family  = "Beck",
             role    = c("ctb"),
             email   = "cole.beck@vumc.org" ),
			person(given   = "Charles",
			       family  = "Dupont",
						 role    = "ctb") )
Depends: R (>= 4.2.0)
Imports: methods, ggplot2, cluster, rpart, nnet, foreign, gtable, grid,
        gridExtra, data.table, htmlTable (>= 1.11.0), viridisLite,
        htmltools, base64enc, colorspace, rmarkdown, knitr, Formula
Suggests: survival, qreport, acepack, chron, rms, mice, rstudioapi,
        tables, plotly (>= 4.5.6), rlang, VGAM, leaps, pcaPP, digest,
        parallel, polspline, abind, kableExtra, rio, lattice,
        latticeExtra, gt, sparkline, jsonlite, htmlwidgets, qs2,
        getPass, keyring, safer, htm2txt, boot
Description: Contains many functions useful for data
	analysis, high-level graphics, utility operations, functions for
	computing sample size and power, simulation, importing and annotating datasets,
	imputing missing values, advanced table making, variable clustering,
	character string manipulation, conversion of R objects to LaTeX and html code,
	recoding variables, caching, simplified parallel computing, encrypting and decrypting data using a safe workflow, general moving window statistical estimation, and assistance in interpreting principal component analysis.
License: GPL (>= 2)
LazyLoad: Yes
URL: https://hbiostat.org/R/Hmisc/
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-06-18 19:06:02 UTC; harrelfe
Author: Frank E Harrell Jr [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8271-5493>),
  Cole Beck [ctb],
  Charles Dupont [ctb]
Maintainer: Frank E Harrell Jr <fh@fharrell.com>
Repository: CRAN
Date/Publication: 2026-06-19 05:10:39 UTC
