\name{legendfunctions}
\alias{legendfunctions}
\alias{Key}
\alias{sKey}
\alias{Key2}
\title{Legend Creation Functions}
\description{
  Wrapers to plot defined legend ploting functions
}
\usage{
Key(...)
Key2(...)
sKey(...)
}
\arguments{
  \item{\dots}{arguments to pass to wrapped functions}
}
